package com.fr.plugin.nnsz.sms;

import com.fr.general.PropertiesUtils;
import com.fr.json.JSONArray;
import com.fr.json.JSONObject;
import com.fr.log.FineLoggerFactory;
import com.fr.plugin.nnsz.sms.action.SmsAction;
import com.fr.plugin.nnsz.sms.client.SMSClient;
import com.fr.plugin.nnsz.sms.entity.SmsRecord;
import com.fr.plugin.transform.FunctionRecorder;
import com.fr.stable.fun.impl.AbstractSMSServiceProvider;

import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;

/**
 * @Author fr.open
 * @Date 2020/11/3
 * @Description
 **/
@FunctionRecorder
public class SmsService extends AbstractSMSServiceProvider {

    private SMSClient smsClient;

    private String url;

    public SmsService() {
        String ecName = PropertiesUtils.getProperties("conf").getProperty("ecName");
        FineLoggerFactory.getLogger().info("ecName config is {}", ecName);
        String apid = PropertiesUtils.getProperties("conf").getProperty("apId");
        FineLoggerFactory.getLogger().info("apId config is {}", apid);
        String secretKey = PropertiesUtils.getProperties("conf").getProperty("secretKey");
        FineLoggerFactory.getLogger().info("secretKey config is {}", secretKey);
        String sign = PropertiesUtils.getProperties("conf").getProperty("sign");
        FineLoggerFactory.getLogger().info("sign config is {}", sign);
        String addSerial = PropertiesUtils.getProperties("conf").getProperty("addSerial");
        FineLoggerFactory.getLogger().info("addSerial config is {}", addSerial);
        url = PropertiesUtils.getProperties("conf").getProperty("url");
        FineLoggerFactory.getLogger().info("url config is {}", url);
        smsClient = new SMSClient(apid, secretKey, ecName, sign, addSerial, url);
    }

    @Override
    public Map<String, String> mapping() {
        Map<String, String> map = new HashMap<>();
        map.put("10", "【xxxx中心】尊敬的管理员，#taskname#于#time#运行失败，请知晓。");
        map.put("11", "【xxxx中心】尊敬的#name#，您有一个工单号为：#order_number#的待处理工单，请您及时处理！");
        map.put("13", "【xxxx中心】您好，#webname#系统内存持续#m#分钟内存高于#n#，可能存在宕机风险，请及时关注。");
        map.put("14", "【xxxx中心】尊敬的管理员，#taskname#于#time#运行失败，请知晓。");
        map.put("15", "【xxxx中心】您好，#taskname#于#time#运行成功。");
        map.put("16", "【xxxx中心】您的手机验证码为#Verifiecode#，请于10分钟内正确输入。");
        map.put("17", "【xxxx中心】您好，#webname#系统内存持续#m#分钟内存高于#n#，可能存在宕机风险，请及时关注。");
        map.put("18", "【xxxx中心】恭喜！您的短信服务已经配置成功。");
        map.put("19", "【xxxx中心】您好，#taskname#于#time#运行成功。");
        map.put("20", "【xxxx中心】您的手机验证码为#verifiecode#，请于10分钟内正确输入。");
        map.put("49", "【xxxx中心】您好，#webname#系统日志文件已大于#logsize#M，请及时登录平台进行日志清理。");
        map.put("50", "【xxxx中心】您好，#webname#系统#clustername#内存持续#m#分钟内存高于#n#，可能存在宕机风险，请及时关注。");
        map.put("51", "【xxxx中心】你好，#task#出错，请及时处理。该任务开始执行时间：#time#");
        map.put("53", "【xxxx中心】上报任务 #task#，已经到您这里#time#，请尽快处理！");
        map.put("63", "【xxxx中心】系统检测到，节点#node_id#的系统时间与其他节点不一致。请配置时间服务器，实现节点时间的自动同步。");
        map.put("64", "【xxxx中心】节点#node_id#，非正常脱离集群环境。请重启该节点，加入集群。");
        map.put("89", "【xxxx中心】节点#nodename#，与节点#node1name#的jar包不一致，将影响集群工程的稳定性，请前往集群节点管理页面查看详细异常信息，并及时处理。");
        map.put("90", "【xxxx中心】节点#nodename#情况异常，用户不能正常访问，请及时检查该节点状态。");
        map.put("125", "【xxxx中心】您有个#proname#任务即将过期，请您尽快办理。");
        map.put("127", "【xxxx中心】您有个#proname#任务需要处理，请您尽快办理。发起人：#startpeople#，发起时间：#starttime#。");
        map.put("134", "【xxxx中心】Redis集群#ip_port#节点已无法正常使用，可能原因为：节点宕机、内存已满、其他异常。为避免影响用户使用，请前往状态服务器配置页面查看详情，并及时处理。");
        map.put("135", "【xxxx中心】文件服务器出现无法读写的情况，可能原因为：文件服务器宕机、磁盘已满、其他异常。为避免影响用户使用，请及时检查文件服务器状态。");
        map.put("136", "【xxxx中心】您好，#webname#系统#clustername#当前负载状态过高，可能存在宕机风险，请及时关注。建议使用管理系统-智能运维-云端运维功能分析当前系统存在的性能问题。");
        map.put("239", "【xxxx中心】您好，预警任务#warningname#达到阈值被触发，请及时关注！模板路径：#templatePath#。");
        map.put("264", "【xxxx中心】更新任务「#job_name#」结束。任务开始于#year#年#month#月#day#日#hr_min#，累计耗时#c_hr#时#c_min#分#c_sec#秒，完成任务：基础表更新 #success_basetable#/#total_basetable# ，自助数据集更新 #success_dataset#/#total_dataset# ， 关联更新 #success_relation#/#total_relation#。");
        map.put("265", "【xxxx中心】报表系统已宕机，请访问运维工具关注问题处理状态或及时进行系统重启。");
        map.put("269", "【xxxx中心】检查到系统环境配置存有不合理项，请及时查看并改正不合理项。");
        map.put("266", "【xxxx中心】报表系统已宕机，自动重启系统失败，请及时进行手动重启。");
        map.put("276", "【xxxx中心】你好，[#taskname#]备份失败，请及时处理，备份时间：#time#。");
        map.put("367", "【xxxx中心】集群节点#node_name#与基准节点存在不一致文件，且无法自动同步。请检查该节点状态。");
        map.put("368", "【xxxx中心】集群节点#node_name#与基准节点存在不一致文件，已自动同步与基准节点一致，不一致文件备份在该节点工程WEB-INF/#directory#/下。");
        map.put("998", "【xxxx中心】节点#nodename1#与节点#nodename2#之间通信异常，无法加入节点管理，请检查集群节点间通信端口是否已开放[TCP:7800,7810, 7820,7830, 7840, 7850,7860,7870][UDP:45588～65536 随机端口]。");
        map.put("999", "【xxxx中心】节点#node_name#的#type#模块存在异常，暂无法正常提供服务，请及时对异常状况进行排查");
        return map;
    }

    @Override
    public Response sendTest(String s) {
        return null;
    }

    @Override
    public Response send(String template, String mobile, JSONObject jsonObject, String receiver) throws Exception {
        Iterator<String> it = jsonObject.keys();
        while (it.hasNext()) {
            String key = it.next();
            template = template.replace(key, jsonObject.getString(key));
        }
        String res = smsClient.sendMsg(mobile, template);
        SmsRecord record = new SmsRecord();
        record.setUrl(url);
        record.setContent(template);
        record.setMobile(mobile);
        record.setResult(res);
        SyncDBAccessProvider.getDbAccessor().runDMLAction(new SmsAction(record));
        return Response.create(Response.RES_STATUS_SUCCESS, "发送普通短信成功", JSONObject.create());
    }

    @Override
    public Response batchSendSMS(String template, List<String> mobiles, JSONArray params, List<String> receivers) throws Exception {
        for (int i = 0; i < params.size(); i++) {
            send(template, receivers.get(i), params.getJSONObject(i), receivers.get(i));
        }
        return Response.create(Response.RES_STATUS_SUCCESS, "发送批量短信成功", JSONObject.create());
    }
}
